==> plugin-center-api-1.0.19-20181022.101608-2-sources.jar: cn/com/duiba/plugin/center/api/dto/ActivityOrderDto.java <==
package cn.com.duiba.plugin.center.api.dto;

import java.io.Serializable;

/**
 * ClassName:ActivityOrderDto<br/>
 *
 * @author gey
 * @version 1.0
 * @Description: 插件订单
 * @date 创建时间：2018/5/9  15:29
 * @since JDK 1.8
 **/
public class ActivityOrderDto implements Serializable {

    private static final long serialVersionUID = 1577272848500604513L;

    public static final String TYPE_PLUGIN = "plugin";//插件活动
    public static final String TYPE_ELASTIC_GIFTS = "elasticGifts";//弹层活动
    public static final String TYPE_SIGN = "sign";//签到
    public static final String TYPE_COLLECT_RULE = "collectRule";//集卡规则

    private String orderNum;
    private Long consumerId;
    private Long appId;
    private String partnerUserId;
    private Long duibaActivityId;
    private Long appActivityId;
    private String activityType;
    private Long consumeCredits;
    private Long addCredits;
    private Long activityOptionId;
    private String activityOptionName;
    private String activityOptionType;
    private String facePrice;
    private Long appItemId;
    private Long itemId;
    private Long gid;
    private String gtype;
    private Integer consumeCreditsStatus;
    private Integer addCreditsStatus;
    private Integer exchangeStatus;
    private String ip;
    private Long couponId;
    private String developerBizId;
    private String addCreditsDevBizId;
    private String mainOrderNum;
    private String error4admin;
    private String error4consumer;
    private String error4developer;

    public String getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }

    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    public Long getDuibaActivityId() {
        return duibaActivityId;
    }

    public void setDuibaActivityId(Long duibaActivityId) {
        this.duibaActivityId = duibaActivityId;
    }

    public Long getAppActivityId() {
        return appActivityId;
    }

    public void setAppActivityId(Long appActivityId) {
        this.appActivityId = appActivityId;
    }

    public String getActivityType() {
        return activityType;
    }

    public void setActivityType(String activityType) {
        this.activityType = activityType;
    }

    public Long getConsumeCredits() {
        return consumeCredits;
    }

    public void setConsumeCredits(Long consumeCredits) {
        this.consumeCredits = consumeCredits;
    }

    public Long getAddCredits() {
        return addCredits;
    }

    public void setAddCredits(Long addCredits) {
        this.addCredits = addCredits;
    }

    public Long getActivityOptionId() {
        return activityOptionId;
    }

    public void setActivityOptionId(Long activityOptionId) {
        this.activityOptionId = activityOptionId;
    }

    public String getActivityOptionName() {
        return activityOptionName;
    }

    public void setActivityOptionName(String activityOptionName) {
        this.activityOptionName = activityOptionName;
    }

    public String getActivityOptionType() {
        return activityOptionType;
    }

    public void setActivityOptionType(String activityOptionType) {
        this.activityOptionType = activityOptionType;
    }

    public String getFacePrice() {
        return facePrice;
    }

    public void setFacePrice(String facePrice) {
        this.facePrice = facePrice;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public Long getGid() {
        return gid;
    }

    public void setGid(Long gid) {
        this.gid = gid;
    }

    public String getGtype() {
        return gtype;
    }

    public void setGtype(String gtype) {
        this.gtype = gtype;
    }

    public Integer getConsumeCreditsStatus() {
        return consumeCreditsStatus;
    }

    public void setConsumeCreditsStatus(Integer consumeCreditsStatus) {
        this.consumeCreditsStatus = consumeCreditsStatus;
    }

    public Integer getAddCreditsStatus() {
        return addCreditsStatus;
    }

    public void setAddCreditsStatus(Integer addCreditsStatus) {
        this.addCreditsStatus = addCreditsStatus;
    }

    public Integer getExchangeStatus() {
        return exchangeStatus;
    }

    public void setExchangeStatus(Integer exchangeStatus) {
        this.exchangeStatus = exchangeStatus;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public Long getCouponId() {
        return couponId;
    }

    public void setCouponId(Long couponId) {
        this.couponId = couponId;
    }

    public String getDeveloperBizId() {
        return developerBizId;
    }

    public void setDeveloperBizId(String developerBizId) {
        this.developerBizId = developerBizId;
    }

    public String getAddCreditsDevBizId() {
        return addCreditsDevBizId;
    }

    public void setAddCreditsDevBizId(String addCreditsDevBizId) {
        this.addCreditsDevBizId = addCreditsDevBizId;
    }

    public String getMainOrderNum() {
        return mainOrderNum;
    }

    public void setMainOrderNum(String mainOrderNum) {
        this.mainOrderNum = mainOrderNum;
    }

    public String getError4admin() {
        return error4admin;
    }

    public void setError4admin(String error4admin) {
        this.error4admin = error4admin;
    }

    public String getError4consumer() {
        return error4consumer;
    }

    public void setError4consumer(String error4consumer) {
        this.error4consumer = error4consumer;
    }

    public String getError4developer() {
        return error4developer;
    }

    public void setError4developer(String error4developer) {
        this.error4developer = error4developer;
    }
}

==> plugin-center-api-1.1.9-sources.jar: cn/com/duiba/plugin/center/api/dto/ActivityOrderDto.java <==
package cn.com.duiba.plugin.center.api.dto;

import java.io.Serializable;

/**
 * ClassName:ActivityOrderDto<br/>
 *
 * @author gey
 * @version 1.0
 * @Description: 插件订单
 * @date 创建时间：2018/5/9  15:29
 * @since JDK 1.8
 **/
public class ActivityOrderDto implements Serializable {

    private static final long serialVersionUID = 1577272848500604513L;

    public static final String TYPE_PLUGIN = "plugin";//插件活动
    public static final String TYPE_ELASTIC_GIFTS = "elasticGifts";//弹层活动
    public static final String TYPE_SIGN = "sign";//签到
    public static final String TYPE_COLLECT_RULE = "collectRule";//集卡规则
    public static final String TYPE_COLLECT_DEVELOPER = "collectForDeveloper";//开发者的集卡活动


    private String orderNum;
    private Long consumerId;
    private Long appId;
    private String partnerUserId;
    private Long duibaActivityId;
    private Long appActivityId;
    private String activityType;
    private Long consumeCredits;
    private Long addCredits;
    private Long activityOptionId;
    private String activityOptionName;
    private String activityOptionType;
    private String facePrice;
    private Long appItemId;
    private Long itemId;
    private Long gid;
    private String gtype;
    private Integer consumeCreditsStatus;
    private Integer addCreditsStatus;
    private Integer exchangeStatus;
    private String ip;
    private Long couponId;
    private String developerBizId;
    private String addCreditsDevBizId;
    private String mainOrderNum;
    private String error4admin;
    private String error4consumer;
    private String error4developer;

    @Deprecated
    private Long sourceId;
    @Deprecated
    private Integer sourceActivityType;
    @Deprecated
    private Long sourceActivityId;

    public String getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }

    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    public Long getDuibaActivityId() {
        return duibaActivityId;
    }

    public void setDuibaActivityId(Long duibaActivityId) {
        this.duibaActivityId = duibaActivityId;
    }

    public Long getAppActivityId() {
        return appActivityId;
    }

    public void setAppActivityId(Long appActivityId) {
        this.appActivityId = appActivityId;
    }

    public String getActivityType() {
        return activityType;
    }

    public void setActivityType(String activityType) {
        this.activityType = activityType;
    }

    public Long getConsumeCredits() {
        return consumeCredits;
    }

    public void setConsumeCredits(Long consumeCredits) {
        this.consumeCredits = consumeCredits;
    }

    public Long getAddCredits() {
        return addCredits;
    }

    public void setAddCredits(Long addCredits) {
        this.addCredits = addCredits;
    }

    public Long getActivityOptionId() {
        return activityOptionId;
    }

    public void setActivityOptionId(Long activityOptionId) {
        this.activityOptionId = activityOptionId;
    }

    public String getActivityOptionName() {
        return activityOptionName;
    }

    public void setActivityOptionName(String activityOptionName) {
        this.activityOptionName = activityOptionName;
    }

    public String getActivityOptionType() {
        return activityOptionType;
    }

    public void setActivityOptionType(String activityOptionType) {
        this.activityOptionType = activityOptionType;
    }

    public String getFacePrice() {
        return facePrice;
    }

    public void setFacePrice(String facePrice) {
        this.facePrice = facePrice;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public Long getGid() {
        return gid;
    }

    public void setGid(Long gid) {
        this.gid = gid;
    }

    public String getGtype() {
        return gtype;
    }

    public void setGtype(String gtype) {
        this.gtype = gtype;
    }

    public Integer getConsumeCreditsStatus() {
        return consumeCreditsStatus;
    }

    public void setConsumeCreditsStatus(Integer consumeCreditsStatus) {
        this.consumeCreditsStatus = consumeCreditsStatus;
    }

    public Integer getAddCreditsStatus() {
        return addCreditsStatus;
    }

    public void setAddCreditsStatus(Integer addCreditsStatus) {
        this.addCreditsStatus = addCreditsStatus;
    }

    public Integer getExchangeStatus() {
        return exchangeStatus;
    }

    public void setExchangeStatus(Integer exchangeStatus) {
        this.exchangeStatus = exchangeStatus;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public Long getCouponId() {
        return couponId;
    }

    public void setCouponId(Long couponId) {
        this.couponId = couponId;
    }

    public String getDeveloperBizId() {
        return developerBizId;
    }

    public void setDeveloperBizId(String developerBizId) {
        this.developerBizId = developerBizId;
    }

    public String getAddCreditsDevBizId() {
        return addCreditsDevBizId;
    }

    public void setAddCreditsDevBizId(String addCreditsDevBizId) {
        this.addCreditsDevBizId = addCreditsDevBizId;
    }

    public String getMainOrderNum() {
        return mainOrderNum;
    }

    public void setMainOrderNum(String mainOrderNum) {
        this.mainOrderNum = mainOrderNum;
    }

    public String getError4admin() {
        return error4admin;
    }

    public void setError4admin(String error4admin) {
        this.error4admin = error4admin;
    }

    public String getError4consumer() {
        return error4consumer;
    }

    public void setError4consumer(String error4consumer) {
        this.error4consumer = error4consumer;
    }

    public String getError4developer() {
        return error4developer;
    }

    public void setError4developer(String error4developer) {
        this.error4developer = error4developer;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public Integer getSourceActivityType() {
        return sourceActivityType;
    }

    public void setSourceActivityType(Integer sourceActivityType) {
        this.sourceActivityType = sourceActivityType;
    }

    public Long getSourceActivityId() {
        return sourceActivityId;
    }

    public void setSourceActivityId(Long sourceActivityId) {
        this.sourceActivityId = sourceActivityId;
    }
}
